@echo off

REM  256K Cartridge Concatenation Program
REM  ------------------------------------
REM  By Adam Trionfo
REM
REM  For use with AtariMax Astrocade 256K Bankswitched Flashcart
REM  (c) 2011 Steven J Tucker
REM  
REM  The batch file takes a 4K (or less) Bally/Astrocade program file and 
REM  places it at $3F000-$3FFFF of a 256K file.  This location is the 64'th
REM  bank (Bank 63) of the cart, which is mapped to $2000, the start of the
REM  Bally/Astrocade console's cartridge area.
REM
REM  This file is meant to be updated for use with your programs.
REM  
REM  Files Required:
REM  ---------------
REM     1) pad128k.bin  (An empty 128K file)
REM     2) Bank32.bin   (Bank 32, stored at $20000-$20FFF)
REM     3) pad120K.bin  (An empty 120K file)
REM     4) BankTest.bin (The Astrocade Executable Program)
REM
REM  Files Created:
REM  --------------
REM  256kprog.bin       (The final 256K executable file for use with Flashcart)
REM  256kprog.old       (The previous version of 256kprog.bin is renamed to this)
REM
REM  Version:      1.1 (Sept. 1, 2011) First release
REM  Version       1.0 (Aug. 30, 2011)
REM  Written by:   Adam Trionfo based on example code by Ward Shrake
REM  Last updated: Sept. 1, 2011

REM  Delete old version of 256K Flashcart program, create new "old" verion,
REM  and then delete the previous version of the Flashcart program.

DEL 256kprog.old
copy 256kprog.bin 256kprog.old
DEL 256kprog.bin

REM  Create new Flashcart Program

copy /b pad128k.bin+Bank32.bin+pad120K.bin+BankTest.bin 256kprog.bin

REM  When the MESS emulator supports this bankswitching scheme then 
REM  the final binary to the MESS directory will be usefull for
REM  testing it.  Until then, this line is commented-out.

REM  copy 256kprog.bin F:\Astrocade\_Programming_(Test_Area)\MESS\mess0142b\software\astrocde


REM  Pause the program so that the user can see that the program did
REM  ran properly.  Clear the screen and present the user with the
REM  newly created file which will show the new file creation date and
REM  time.  Also, show the user the correct file size so that it can
REM  be compared with the new Flashcart file.

CLS
DIR 256kprog.bin
ECHO .
ECHO Correct full-size Flashcart file size: 262,144 bytes. 
ECHO .
PAUSE
DIR /on /w